diff --git a/datastore_server/source/java/ch/systemsx/cisd/openbis/dss/generic/server/graph/AbstractTabularDataGraph.java b/datastore_server/source/java/ch/systemsx/cisd/openbis/dss/generic/server/graph/AbstractTabularDataGraph.java
index eeea829af2b83e8f36cc28fd93a3dd3d7be1d6b3..d84963cf85d6f08bff6213590310ba87bfddd670 100644
--- a/datastore_server/source/java/ch/systemsx/cisd/openbis/dss/generic/server/graph/AbstractTabularDataGraph.java
+++ b/datastore_server/source/java/ch/systemsx/cisd/openbis/dss/generic/server/graph/AbstractTabularDataGraph.java
@@ -214,17 +214,33 @@ abstract class AbstractTabularDataGraph<T extends TabularDataGraphConfiguration>
     protected JFreeChart createErrorChart()
     {
         DefaultXYDataset dataset = new DefaultXYDataset();
-        JFreeChart chart =
-                ChartFactory.createXYAreaChart(
-                        "Error : Could not find requested columns in dataset.", // title
-                        getXAxisLabel(), // x-axis label
-                        getYAxisLabel(), // y-axis label
-                        dataset, // data
-                        PlotOrientation.VERTICAL, // plot orientation
-                        false, // create legend?
-                        false, // generate tooltips?
-                        false // generate URLs?
-                        );
+        JFreeChart chart = ChartFactory.createXYAreaChart("", // title
+                "", // x-axis label
+                "", // y-axis label
+                dataset, // data
+                PlotOrientation.VERTICAL, // plot orientation
+                false, // create legend?
+                false, // generate tooltips?
+                false // generate URLs?
+                );
+
+        // Set the background color
+        chart.setBackgroundPaint(Color.WHITE);
+        chart.setBorderVisible(false);
+
+        // Configure the plot
+        XYPlot plot = (XYPlot) chart.getPlot();
+        plot.setBackgroundPaint(Color.WHITE);
+        plot.setDomainGridlinesVisible(false);
+        plot.setRangeGridlinesVisible(false);
+        plot.setDomainCrosshairVisible(false);
+        plot.setRangeCrosshairVisible(false);
+        plot.setDomainZeroBaselineVisible(false);
+        plot.setRangeZeroBaselineVisible(false);
+        plot.setForegroundAlpha(0.f);
+        plot.setOutlineVisible(false);
+        plot.setDomainAxis(null);
+        plot.setRangeAxis(null);
 
         return chart;
     }